@@ -101,7 +101,8 @@ class TaskAssignator:
                                 f"assigned ipt {ipt} -> ico {ico} ->"+\
                                 f"ids {ids}"
                                 level = 20
-                                await scheduler.send_log("Assignator", level, msg, [])                                
+                                scheduler.queue_log.put(("Assignator",
+                                                         msg, level, {}))
 
                                 dt_group.remove(element)
 
@@ -117,8 +118,8 @@ class TaskAssignator:
                             f"assigned ipt {ipt} -> ico {ico} ->"+\
                             f"ids {ids}"
                             level = 20
-                            
-                            await scheduler.send_log("Assignator", level, msg, [])
+                            scheduler.queue_log.put(("Assignator",
+                                                     msg, level, {}))
 
                             print(self.scheduler.assigned_tasks)
                             self.scheduler.add_sta_assigned(
@@ -131,8 +132,8 @@ class TaskAssignator:
                         msg = f"All slots are "+\
                               f"used, can't add the station {code} ids {ids}"
                         level = 30 #warning
-                        await scheduler.send_log("Assignator", level, msg, [])
-                        
+                        scheduler.queue_log.put(("Assignator", msg,
+                                                 level, {}))
                 queue_tasks.task_done()
             else:
                 pass
